@@ -8,11 +8,14 @@ class Intents:
 
     """
 	
-	def all(self):
+	@classmethod
+	def all(cls):
 		return 28671
 		
-	def members(self):
+	@classmethod
+	def members(cls):
 		return 255
 		
-	def presences(self):
+	@classmethod
+	def presences(cls):
 		return 32512
\ No newline at end of file
